#
# spec file for package obs-service-cargo
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           obs-service-cargo
Summary:        OBS Source Service and utilities for Rust software packaging
License:        MPL-2.0
Group:          Development/Tools/Building
# Repository name subject to change
URL:            https://github.com/openSUSE-Rust/%{name}
Version:        1.3.6
Release:        4.1
Source0:        https://github.com/openSUSE-Rust/%{name}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig(libzstd)
Requires:       cargo-vendor-filterer
Requires:       (cargo or rustup)
# At 0.6.0, vendor was introduced so we obsolete versions before that
Conflicts:      obs-service-cargo_vendor
Obsoletes:      obs-service-cargo_vendor
Provides:       obs-service-cargo_vendor = %{version}
# At 0.7.0, audit was introduced so we obsolete versions before that
Conflicts:      obs-service-cargo_audit
Obsoletes:      obs-service-cargo_audit
Provides:       obs-service-cargo_audit = %{version}

%description
This is an OBS Source Service that contains two main utilities:
- OBS Service Cargo Vendor
- OBS Service Cargo Audit

This vendors and audits dependencies for packaging Rust software.

%prep
%autosetup -a1

%build
%{cargo_build}

%install
mkdir -p %{buildroot}%{_prefix}/lib/obs/service
install -m0755 %{_builddir}/%{name}-%{version}/target/release/cargo_vendor %{buildroot}%{_prefix}/lib/obs/service
install -m0755 %{_builddir}/%{name}-%{version}/target/release/cargo_audit  %{buildroot}%{_prefix}/lib/obs/service
install -m0644 cargo_vendor.service %{buildroot}%{_prefix}/lib/obs/service
install -m0644 cargo_audit.service %{buildroot}%{_prefix}/lib/obs/service

%files
%defattr(-,root,root)
%doc README.md
%license LICENSE
%dir %{_prefix}/lib/obs
%{_prefix}/lib/obs/service

%changelog
* Tue Sep  3 2024 Gordon Leung <pirateclip@protonmail.com>
- Update vendored deps to resolve boo#1230083
* Mon Jul 29 2024 Gordon Leung <pirateclip@protonmail.com>
- Bump constraints, zsystems still keeps failing due to OOM
* Tue Jun 25 2024 Gordon Leung <pirateclip@protonmail.com>
- Add _constraints to stop s390x out of memory build fails
* Tue Jun 11 2024 Gordon Leung <pirateclip@protonmail.com>
- Fix build failures caused by the topmost folder being renamed
  from obs-service-cargo_vendor to obs-service-cargo
* Thu Jun  6 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.3.6
  * Fix Clippy error and add Clippy CI
  * fix: vendor-filterer --all-features rather than --all-features=true
  * internet_points: Add Pi-Cla
  * 20240523 ensure to regenerate lockfiles if vendor set to false
  * doc: fix warning indicator
  * fix again warn indicator
* Thu May  2 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.3.2:
  * dependencies update
- Update resolves security incidents. I believe this does not really affect
  how obs-service-cargo behaves but for now, I just want to avoid the alerts.
* Sat Mar 30 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.3.1:
  * docs: update CHANGELOG
  * docs: add CONTRIBUTORS.md
  * cargo-vendor-filterer now supports --sync
* Sat Mar 23 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add cargo vendor-filterer as requirement.
- Set `filter` to true in _service file.
- Update vendored dependencies with filterer.
* Sat Mar  9 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.2.1:
  * Add experimental vendor_filterer support
* Sat Mar  2 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.1.0:
  * make tarballs reproducible
* Sun Jan 14 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to 1.0.0:
  * No code change *
* Sun Dec 24 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to 0.9.0:
  * No code change *
* Mon Dec 11 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.21:
  * Improve errors with outpath
* Thu Dec  7 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.20:
  * added bz2 mime
  * add fixes to make bz2 mime supported
* Tue Dec  5 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.18:
  * (de)compress: add Bz2 compression
  * refactor return types and initial boilerplate for bz2 compress
  * nitpick. slight refactor because Ok(()) looks yuck in some contexts
  * it should be `--output` if we want to download a file
* Fri Nov 24 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.15:
  * fix: we also include build_dependencies
  * test: add VBox-Starter in runtests.sh
  * fix: check also the targets section
  * misc: nitpick. remove small space
  * fix typo
  * docs: put warning on README
* Tue Nov 21 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.12:
  * improv: reintroduced tag in README
  * Add tagging
  * docs: add possible vendor failures in README
  * make cargotoml usage clearer
* Sat Nov 18 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.10:
  * docs: update README
  * move lints to configuration manifest
  * an improvement of commit 24aaa0056
  * configure rust version and toolchain"
  * check if there are lockfiles from aforementioned manifest paths
  * fix: check if dependencies section is empty or not
  * misc: remove redundant messages
  * improvement: better handling on when and when not to vendor
* Fri Nov 17 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Remove cargo_config. Part of vendored tarball now
- Update to 0.8.9:
  * dummy determine the path of the lockfile
* Fri Nov 17 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to 0.8.8:
  * clippy: change match to if let
  * docs: add dependencies section in the README
  * fix: just warn and don't return an error
  * fix: hasdeps should inherit should_vendor value
  * fix: also join the paths from `prjdir`
  * Remove tags, fix multitoml vendor, automatically add .cargo/config
  * fix multi cargo issue
  * do not exit process when terminfo is not found.
- Disable update. Cargo cannot find glob crate when trying to update.
* Tue Oct 31 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.4:
  * fix: also check attempt to vendor if it is also a workspace
* Tue Oct 31 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.8.3:
  * misc: add stop sign in error message
  * improve error handling impl
  * fix: also make sure it really has no deps
  * utils: exit vendor step if no dependencies found
  * update README again
  * update README
  * docs: update README regarding the new flag
  * all: apply clippy lint suggestions
  * fix: also copy top-level folder if src is a directory
  * Rework of compression and vendoring to be clearer
  * Minor output improvements
  * fix: also copy top-level folder if src is a directory
  * update email address in manifest file
  * remove unused dead code
  * clippy: apply clippy suggestions
* Thu Oct 12 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to release 0.8.0:
  * audit is no-op and it is now part of vendor process.
  * cargo_audit binary will execute nothing now.
* Wed Oct 11 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to release 0.7.5:
  * globbed tar now supports lexicographical order
  * improved rustsec output
* Mon Oct  9 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to release 0.7.4:
  * fix: decompressed tarball may or may not have a top-level folder
* Sat Oct  7 2023 William Brown <william.brown@suse.com>
- Change obsoletes to not list a version as we obsolete all versions.
* Sat Oct  7 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to release 0.7.3.
  * small fixes and changes
* Sat Oct  7 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 0.7.1. No changes.
* Sat Oct  7 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to 0.7.0:
  * refactor cargo vendor
  * feature audit
* Sun Sep 10 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Change to 0.6.0 release
* Sun Sep 10 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for obs-service-cargo. 0.6.0-alpha
